@@ -1,10 +1,12 @@
-/** kate-script
- * name: ada
- * license: LGPL
- * author: Trevor Blight <trevor-b@ovi.com>
- * revision: 1
- * kate-version: 3.4
- *
+var katescript = {
+    "name": "ada",
+    "author": "Trevor Blight <trevor-b@ovi.com>",
+    "license": "LGPL",
+    "revision": 2,
+    "kate-version": "5.1"
+}; // kate-script-header, must be at the start of the file without comments, pure json
+
+/**
  * This file is part of the Kate Project.
  *
  * This library is free software; you can redistribute it and/or
